@@ -40,8 +40,8 @@ class Base:
 class OEBuild(Base):
     src_dir: str
     build_dir: str
-    envsetup: str
-    target: str
+    envsetup: str = None
+    target: str = None
     distro: str = None
     build_only: bool = False
     sync_only: bool = False
@@ -87,92 +87,151 @@ class OEBuild(Base):
             for git_entry in self.sources.get("git_trees"):
                 self.git_trees.append(self.Git(**git_entry))
 
-    def validate(self):
+    @staticmethod
+    def validate(oebuild_data):
+
+        if oebuild_data.get("sources"):
+            check_instance(
+                oebuild_data["sources"],
+                dict,
+                f"Unexpected value of sources in build definition: {oebuild_data['sources']}, expected dictionary object with either git_trees or repo",
+            )
+            if oebuild_data["sources"].get("repo") and oebuild_data["sources"].get(
+                "git_trees"
+            ):
+                raise (
+                    TuxbakeParsingError(
+                        "repo or git_trees may be specified, but not both"
+                    )
+                )
+
+            elif oebuild_data["sources"].get("repo"):
+                repo = oebuild_data["sources"]["repo"]
+                check_instance(
+                    repo,
+                    dict,
+                    f"Unexpected value of repo in sources of build definition: {repo}, expected dictionary object with url, branch and manifest",
+                )
+                for val in ["url", "branch", "manifest"]:
+                    if val not in repo.keys():
+                        raise (
+                            TuxbakeParsingError(
+                                f"Please specify the mandatory field {val} in repo of sources"
+                            )
+                        )
+                url, branch, manifest = repo["url"], repo["branch"], repo["manifest"]
+                validate_git_repo(url)
+                check_instance(
+                    branch,
+                    str,
+                    f"Unexpected argument for branch: {branch}, expected string: '{branch}'",
+                )
+                check_instance(
+                    manifest,
+                    str,
+                    f"Unexpected argument for manifest: {manifest}, expected string: '{manifest}'",
+                )
+                ext = os.path.splitext(manifest)[1]
+                if manifest and ext.lower() != ".xml":
+                    raise (
+                        TuxbakeParsingError(
+                            f"unknown manifest file extension: '{ext}', must be '.xml': '{manifest}'"
+                        )
+                    )
+
+            elif oebuild_data["sources"].get("git_trees"):
+                git_trees = oebuild_data["sources"]["git_trees"]
+                check_instance(
+                    git_trees,
+                    list,
+                    f"Unexpected argument for git_trees: {git_trees}, expected list: '{git_trees}'",
+                )
+
+                for git_obj in git_trees:
+                    check_instance(
+                        git_obj,
+                        dict,
+                        f"Unexpected values of git_trees List: {git_obj}, expected dictionary objects in the List",
+                    )
+                    if "url" not in git_obj.keys():
+                        raise (
+                            TuxbakeParsingError(
+                                "Please specify the mandatory field url in git_trees of sources"
+                            )
+                        )
+
+                    url = git_obj["url"]
+                    branch = git_obj.get("branch", "")
+                    ref = git_obj.get("ref", "")
+                    sha = git_obj.get("sha", "")
+                    # validations
+                    validate_git_repo(url)
+                    if branch:
+                        check_instance(
+                            branch,
+                            str,
+                            f"Unexpected argument for branch: {branch}, expected string: '{branch}'",
+                        )
+                    if ref:
+                        validate_git_ref(ref)
+                    if sha:
+                        validate_git_sha(sha)
+            else:
+                raise (TuxbakeParsingError("repo or git_trees must be specified!!"))
+
+        else:
+            raise (
+                TuxbakeParsingError(
+                    "Please specify either git_trees or repo in sources of build definition"
+                )
+            )
+        if oebuild_data.get("envsetup"):
+            check_instance(
+                oebuild_data["envsetup"],
+                str,
+                f"Unexpected argument for envsetup: {oebuild_data['envsetup']}, expected string: '{oebuild_data['envsetup']}'",
+            )
+        else:
+            raise (
+                TuxbakeParsingError("Please specify the envsetup in build definition")
+            )
+
+        if oebuild_data.get("target"):
+            check_instance(
+                oebuild_data["target"],
+                str,
+                f"Unexpected argument for target: {oebuild_data['target']}, expected string: '{oebuild_data['target']}'",
+            )
+        else:
+            raise (TuxbakeParsingError("Please specify the target in build definition"))
+
+        if oebuild_data.get("machine"):
+            check_instance(
+                oebuild_data["machine"],
+                str,
+                f"Unexpected argument for target: {oebuild_data['machine']}, expected string: '{oebuild_data['machine']}'",
+            )
+        else:
+            raise (
+                TuxbakeParsingError("Please specify the machine in build definition")
+            )
 
-        oebuild_data = self.as_dict()
-        check_instance(
-            oebuild_data["envsetup"],
-            str,
-            f"Unexpected argument for envsetup: {oebuild_data['envsetup']}, expected string: '{oebuild_data['envsetup']}'",
-        )
-        check_instance(
-            oebuild_data["target"],
-            str,
-            f"Unexpected argument for target: {oebuild_data['target']}, expected string: '{oebuild_data['target']}'",
-        )
         if oebuild_data.get("distro"):
             check_instance(
                 oebuild_data["distro"],
                 str,
                 f"Unexpected argument for distro: {oebuild_data['distro']}, expected string: '{oebuild_data['distro']}'",
             )
-
-        if oebuild_data.get("repo") and oebuild_data.get("git_trees"):
-            raise (
-                TuxbakeParsingError("repo or git_trees may be specified, but not both")
-            )
-        elif oebuild_data.get("repo"):
-            url, branch, manifest = (
-                oebuild_data["repo"]["url"],
-                oebuild_data["repo"]["branch"],
-                oebuild_data["repo"]["manifest"],
-            )
-            validate_git_repo(url)
-            check_instance(
-                branch,
-                str,
-                f"Unexpected argument for branch: {branch}, expected string: '{branch}'",
-            )
-            check_instance(
-                manifest,
-                str,
-                f"Unexpected argument for manifest: {manifest}, expected string: '{manifest}'",
-            )
-            ext = os.path.splitext(manifest)[1]
-            if manifest and ext.lower() != ".xml":
-                raise (
-                    TuxbakeParsingError(
-                        f"unknown manifest file extension: '{ext}', must be '.xml': '{manifest}'"
-                    )
-                )
-
-        elif oebuild_data.get("git_trees"):
-            check_instance(
-                oebuild_data["git_trees"],
-                list,
-                f"Unexpected argument for git_trees: {oebuild_data['git_trees']}, expected list: '{oebuild_data['git_trees']}'",
-            )
-            git_trees = oebuild_data["git_trees"]
-            for git_object in git_trees:
-
-                check_instance(
-                    git_object,
-                    dict,
-                    f"Unexpected values of git_trees List: {git_object}, expected dictionary objects: '{{{git_object}}}'",
-                )
-                url = git_object["url"]
-                branch = git_object.get("branch", "")
-                ref = git_object.get("ref", "")
-                sha = git_object.get("sha", "")
-
-                # validations
-                validate_git_repo(url)
-                if branch:
-                    check_instance(
-                        branch,
-                        str,
-                        f"Unexpected argument for branch: {branch}, expected string: '{branch}'",
-                    )
-                if ref:
-                    validate_git_ref(ref)
-                if sha:
-                    validate_git_sha(sha)
-
         else:
-            raise (TuxbakeParsingError("repo or git_trees must be specified!!"))
+            raise (TuxbakeParsingError("Please specify the distro in build definition"))
 
         if oebuild_data.get("container"):
             validate_container(oebuild_data["container"])
+        else:
+            raise (
+                TuxbakeParsingError("Please specify the container in build definition")
+            )
+
         if oebuild_data.get("environment"):
             validate_environment(oebuild_data["environment"])
         if oebuild_data.get("local_conf"):
@@ -223,7 +282,7 @@ class OEBuild(Base):
         self._runtime.set_user("tuxbake")
         self._runtime.set_group("tuxbake")
         self._runtime.basename = "build"
-        _container_name = f"docker.io/vishalbhoj/{self.container}"
+        _container_name = f"docker.io/tuxbake/{self.container}"
         if "-local" in self.runtime:
             _container_name = f"{self.image}"
         self._runtime.set_image(f"{_container_name}")
